#
# spec file for package python3-pyside2
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%bcond_without tests

%global flavor %{nil}
%if "%flavor" == "sle15_python_module"
%{?sle15_python_module_pythons}
%{!?sle15_python_module_pythons:ExclusiveArch: donotbuild}
%{!?sle15_python_module_pythons:BuildRequires: no-build-without-sle15_python_module}
%else
# SLE15: python3.6, Tumbleweed: primary python
%define pythons python3
%endif
%global mypython %pythons
%global __mypython %{expand:%%__%{mypython}}
%global mypython_sitearch %{expand:%%%{mypython}_sitearch}
%global mypython_version_nodots %{expand:%%%{mypython}_version_nodots}
%global mypython_soflags %(%__mypython -c "import sysconfig; print(sysconfig.get_config_var('SOABI'))")

# QML imports created and used by examples
%global __requires_exclude qmlimport\\((Charts|TextBalloonPlugin)

Name:           %{mypython}-pyside2
Version:        5.15.12
Release:        2.9
Summary:        Python bindings for Qt
# Legal:
# Most files are LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
# pyside2-tools is GPL-2.0-only
# shiboken2 contains files under GPL-3.0-only WITH Qt-GPL-exception-1.0
License:        LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later) AND GPL-2.0-only AND GPL-3.0-only WITH Qt-GPL-exception-1.0
URL:            https://wiki.qt.io/Qt_for_Python
Source0:        https://download.qt.io/official_releases/QtForPython/pyside2/PySide2-%{version}-src/pyside-setup-opensource-src-%{version}.tar.xz
# PATCH-FIX-OPENSUSE
Patch0:         0001-Always-link-to-python-libraries.patch
# PATCH-FIX-UPSTREAM
Patch1:         0001-Don-t-try-to-install-or-use-uic-rcc-designer-copies.patch
# PATCH-FIX-UPSTREAM
Patch2:         0001-cmake-Don-t-assume-qhelpgenerator-is-in-PATH.patch
# PATCH-FIX-UPSTREAM
Patch3:         0001-Fix-tests-sample_privatector-sample_privatedtor-fail.patch
# Provide the PyPI names
Provides:       %{mypython}-PySide2 = %{version}-%{release}
Provides:       %{mypython}-shiboken2 = %{version}-%{release}
Provides:       %{mypython}-shiboken2_generator = %{version}-%{release}
Requires(post): update-alternatives
Requires(postun):update-alternatives
# SECTION common_dependencies
%if 0%{?suse_version} > 1500
# boo#1210176 - PYSIDE-2268
BuildRequires:  clang15-devel
BuildRequires:  llvm15-libclang13
#!BuildIgnore:  clang16
#!BuildIgnore:  clang17
%else
%if 0%{?sle_version} >= 150600
# boo#1210176 - PYSIDE-2268, PY-2288
BuildRequires:  clang14-devel
BuildRequires:  llvm14-libclang13
#!BuildIgnore:  clang16
#!BuildIgnore:  clang17
%else
BuildRequires:  clang-devel >= 3.9
%endif
%endif
BuildRequires:  %{mypython}-Sphinx
BuildRequires:  %{mypython}-devel
BuildRequires:  %{mypython}-idna
BuildRequires:  %{mypython}-setuptools
BuildRequires:  %{mypython}-urllib3
BuildRequires:  %{mypython}-wheel
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libqt5-qtdeclarative-private-headers-devel
BuildRequires:  libxslt-devel
BuildRequires:  python-rpm-macros
%if %{with tests}
BuildRequires:  Mesa-dri
BuildRequires:  xvfb-run
%endif
# /SECTION
# SECTION essential_modules
BuildRequires:  cmake(Qt5Concurrent)
BuildRequires:  cmake(Qt5Core) >= 5.15
BuildRequires:  cmake(Qt5Network)
BuildRequires:  cmake(Qt5PrintSupport)
BuildRequires:  cmake(Qt5Sql)
BuildRequires:  cmake(Qt5Test)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5X11Extras)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(Qt5XmlPatterns)
# /SECTION
# SECTION optional_modules
BuildRequires:  libQt53DQuickScene2D5
BuildRequires:  cmake(Qt53DAnimation)
BuildRequires:  cmake(Qt53DCore)
BuildRequires:  cmake(Qt53DExtras)
BuildRequires:  cmake(Qt53DInput)
BuildRequires:  cmake(Qt53DLogic)
BuildRequires:  cmake(Qt53DRender)
BuildRequires:  cmake(Qt5Charts)
BuildRequires:  cmake(Qt5DataVisualization)
BuildRequires:  cmake(Qt5Designer)
BuildRequires:  cmake(Qt5Multimedia)
BuildRequires:  cmake(Qt5MultimediaWidgets)
BuildRequires:  cmake(Qt5OpenGL)
BuildRequires:  cmake(Qt5QuickControls2)
BuildRequires:  cmake(Qt5QuickWidgets)
BuildRequires:  cmake(Qt5RemoteObjects)
BuildRequires:  cmake(Qt5Script)
BuildRequires:  cmake(Qt5ScriptTools)
BuildRequires:  cmake(Qt5Scxml)
BuildRequires:  cmake(Qt5Sensors)
BuildRequires:  cmake(Qt5SerialPort)
BuildRequires:  cmake(Qt5Svg)
BuildRequires:  cmake(Qt5TextToSpeech)
BuildRequires:  cmake(Qt5WebChannel)
%ifnarch ppc64 ppc64le s390x
BuildRequires:  cmake(Qt5WebEngineWidgets)
%endif
BuildRequires:  cmake(Qt5WebSockets)
BuildRequires:  cmake(Qt5Widgets)
BuildRequires:  cmake(Qt5Xml)
BuildRequires:  cmake(Qt5XmlPatterns)
# /SECTION

%description
The PySide2 project provides Python bindings for the Qt
application and UI framework.

%package devel
Summary:        Header Files for PySide2
License:        (GPL-2.0-only AND (GPL-2.0-only OR GPL-3.0-or-later) AND GPL-3.0-only WITH Qt-GPL-exception-1.0) OR LGPL-3.0-only
Requires:       %{name} = %{version}
# can be used to disambiguate multiple providers of cmake(PySide2) and cmake(Shiboken2)
Provides:       pyside2_python_abi(%{mypython_soflags}) = %{version}
%if "%{mypython}" != "python3"
# Can only build for one flavor at a time
Conflicts:      python3-pyside2-devel
%endif

%description devel
Files needed for development with the PySide2 bindings
for Qt.

%package examples
Summary:        Examples for using PySide2
License:        BSD-3-Clause
Requires:       %{name} = %{version}
%if "%{mypython}" != "python3"
Conflicts:      python3-pyside2-examples
%endif
BuildArch:      noarch

%description examples
Examples and Tutorials for the PySide2 bindings for Qt.

%prep
%autosetup -p1 -n pyside-setup-opensource-src-%{version}

%build
_libsuffix=$(echo %{_lib} | cut -b4-)

# NOTE:The compiler and linker flags shall not be defined
%cmake \
  -DLIB_SUFFIX:STRING="${_libsuffix}" \
  -DCMAKE_C_FLAGS:STRING="" \
  -DCMAKE_CXX_FLAGS:STRING="" \
  -DCMAKE_EXE_LINKER_FLAGS:STRING="" \
  -DPYTHON_EXECUTABLE:STRING=%{__mypython} \
  -DCMAKE_BUILD_RPATH_USE_ORIGIN:BOOL=ON \
%if %{with tests}
  -DBUILD_TESTS:BOOL=ON
%endif

%cmake_build

%install
%cmake_install

%python_clone -a %{buildroot}%{_bindir}/pyside2-lupdate
%python_clone -a %{buildroot}%{_bindir}/pyside_tool.py
%python_clone -a %{buildroot}%{_bindir}/shiboken2

# Broken and conflicts with python3X-pyside6
rm %{buildroot}%{_bindir}/shiboken_tool.py

# No use on linux
rm %{buildroot}%{_datadir}/PySide2/typesystems/*_{mac,win}.xml

# The cmake superproject forgets these
cp -r build/sources/pyside2/PySide2/*.pyi \
      build/sources/pyside2/PySide2/py.typed \
      build/sources/pyside2/PySide2/support \
    %{buildroot}%{mypython_sitearch}/PySide2/
# this is not ideal, but at least we get some python dist metadata
%{__mypython} setup.py dist_info
for d in *.dist-info; do
  # the commands were copied verbatim, not wrapped by entry-points.
  rm -f $d/entry_points.txt
%if %{pkg_vcmp %{mypython}-setuptools < 63}
  cp -r $d %{buildroot}%{mypython_sitearch}/${d/.dist-info/-%{version}.dist-info}
%else
  cp -r $d %{buildroot}%{mypython_sitearch}/${d}
%endif
done

# Examples must be installed manually
cp -R examples %{buildroot}%{_datadir}/PySide2

%fdupes %{buildroot}%{_datadir}/PySide2/examples/
%fdupes %{buildroot}%{_libqt5_libdir}/cmake/
%fdupes %{buildroot}%{mypython_sitearch}

%check
%if %{with tests}
# Set some environment variables
export PATH=%{_libqt5_bindir}:$PATH
export LD_LIBRARY_PATH=%{buildroot}%{_libqt5_libdir}:$LD_LIBRARY_PATH
export PYTHONPATH=%{buildroot}%{mypython_sitearch}:$PWD/build/sources/pyside2/tests/pysidetest
%if 0%{?sle_version} && 0%{?sle_version} <= 150300
# Leap 15.3: ctest searches the libs before shiboken_paths.py can set the search path (!?)
for binding in $PWD/build/sources/shiboken2/tests/lib*; do
  export LD_LIBRARY_PATH=$binding:$LD_LIBRARY_PATH
done
export LD_LIBRARY_PATH=$PWD/build/sources/pyside2/tests/pysidetest:$LD_LIBRARY_PATH
%endif

%define xvfb_command xvfb-run -s "-screen 0 1600x1200x16 -ac +extension GLX +render -noreset"

# Tests known to fail (listed in build_history/blacklist.txt)
ctest_exclude_regex="QtMultimedia_audio_test"
ctest_exclude_regex="$ctest_exclude_regex|QtQml_javascript_exceptions"
ctest_exclude_regex="$ctest_exclude_regex|QtScriptTools_debugger_test"
ctest_exclude_regex="$ctest_exclude_regex|registry_existence_test"
ctest_exclude_regex="$ctest_exclude_regex|QtWebEngineWidgets_pyside-474-qtwebengineview"
ctest_exclude_regex="$ctest_exclude_regex|QtWebEngineCore_web_engine_custom_scheme"

%if %{mypython_version_nodots} >= 311
# Blacklist broken test with python 3.11
ctest_exclude_regex="$ctest_exclude_regex|signal_enum_test|QtCore_qenum_test"
%endif

%ifarch %{arm}
# bug_307 fails on armv7l only
ctest_exclude_regex="$ctest_exclude_regex|QtWidget_bug_307"
%endif
%ifarch ppc64le s390x
# TODO: investigate/report test failure on PowerPC and s390x
ctest_exclude_regex="$ctest_exclude_regex|QtQml_signal_arguments"
%endif

# Tests are executed from subdirectories. %%ctest can't be used.
%define ctest_command %{shrink:ctest
  --output-on-failure
  --force-new-ctest-process
  --parallel %{_smp_build_ncpus}
  --exclude-regex "($ctest_exclude_regex)"}

pushd build/sources/shiboken2
%{xvfb_command} %{ctest_command}
popd
pushd build/sources/pyside2
%{xvfb_command} %{ctest_command}
popd
%endif

%post
%{?ldconfig}
%python_install_alternative pyside2-lupdate
%python_install_alternative pyside_tool.py
%python_install_alternative shiboken2

%postun
%{?ldconfig}
%python_uninstall_alternative pyside2-lupdate
%python_uninstall_alternative pyside_tool.py
%python_uninstall_alternative shiboken2

%files
%license LICENSE.*
%doc dist/changes*
%python_alternative %{_bindir}/pyside2-lupdate
%python_alternative %{_bindir}/pyside_tool.py
%python_alternative %{_bindir}/shiboken2
%{_libqt5_libdir}/libpyside2.%{mypython_soflags}.so.*
%{_libqt5_libdir}/libshiboken2.%{mypython_soflags}.so.*
%{mypython_sitearch}/PySide2/
%{mypython_sitearch}/PySide2-%{version}.dist-info
%{mypython_sitearch}/shiboken2/
%{mypython_sitearch}/shiboken2-%{version}.dist-info
%{mypython_sitearch}/shiboken2_generator/
%{mypython_sitearch}/shiboken2_generator-%{version}.dist-info

%files devel
%{_datadir}/PySide2/
%{_includedir}/PySide2/
%{_includedir}/shiboken2/
%{_libqt5_libdir}/libpyside2.%{mypython_soflags}.so
%{_libqt5_libdir}/libshiboken2.%{mypython_soflags}.so
%{_libqt5_libdir}/cmake/PySide2-%{version}
%{_libqt5_libdir}/cmake/Shiboken2-%{version}
%{_libqt5_libdir}/pkgconfig/pyside2.pc
%{_libqt5_libdir}/pkgconfig/shiboken2.pc
%{_mandir}/man1/pyside2-lupdate.1%{?ext_man}
%exclude %{_datadir}/PySide2/examples

%files examples
%dir %{_datadir}/PySide2
%{_datadir}/PySide2/examples

%changelog
* Fri Jan 26 2024 Ben Greiner <code@bnavigator.de>
- Enable SLE15 python module for a more modern python than 3.6
  * disambiguate multiple providers of cmake(Pyside2) with
    pyside2_python_abi() provides
- Use llvm14 for 15.6 in order to workaround PYSIDE-2288:
  * Wrong type for QEvent::Type
  * avoids patch like deb#1051886 for libqt5-qtbase
* Fri Jan 12 2024 Antonio Larrosa <alarrosa@suse.com>
- Disable the QtQml_signal_arguments test in s390x just as it was
  disabled in ppc64le to fix building in ALP (bsc#1217025)
* Thu Jan 11 2024 Antonio Larrosa <alarrosa@suse.com>
- Update to 5.15.12
  * Missing includes for g++ 11.3 have been added.
* Mon Oct 30 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.15.11
  * Documentation regarding the clang environment variables has been fixed.
  * Support for Python 3.11 has been added.
  * The GLES build has been fixed.
  * Crashes when using QtDataVisualization's QValue3DAxisFormatter have been fixed.
- Drop patches, merged upstream:
  * 0001-Backport-Fix-GLES-builds.patch
  * python-3.11-compatibility.patch
* Mon Sep 18 2023 Christophe Marin <christophe@krop.fr>
- Add patch to fix failure with Python 3.11.5:
  * 0001-Fix-tests-sample_privatector-sample_privatedtor-fail.patch
* Mon Jun 19 2023 Dmitry Roshchin <dmitry_r@opensuse.org>
- Update to version 5.15.10:
  * Error "Internal C++ object already deleted." when
    using QWidget::nativeParentWidget() has been fixed.
  * A crash in QTextBlock.layout() has been fixed.
- Fix python 3.11 compatibility, temporary blacklist signal_enum_test
  * python-3.11-compatibility.patch
* Wed Jun 14 2023 Jiri Srain <jsrain@suse.com>
- update _constrainsts to 8GB of disk to avoid random build
  failures
* Wed Apr 19 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.15.9
  * QByteArray::__msetitem__() was fixed for big endian archs
  * UNICODE conversion with Python3/Non-Limited API was fixed
- Drop patch, fixed upstream:
  * 0001-Fix-build-with-Python-3.10.patch
* Thu Apr 13 2023 Christophe Marin <christophe@krop.fr>
- Build with LLVM 15 on Tumbleweed
- Add a _constraints file to avoid disk and memory issues
* Wed Jan 11 2023 Christophe Marin <christophe@krop.fr>
- Update to 5.15.8.
  * Check the changes-5.15.8 file for the full list of changes
- Drop patch, merged upstream:
  * 0001-Backport-LLVM-13-fix-from-shiboken6.patch
- Add patch to fix build with recent Python versions:
  * 0001-Fix-build-with-Python-3.10.patch
* Tue Aug  9 2022 Christophe Giboudeaux <christophe@krop.fr>
- Fix the dist-info folder name with python3-setuptools 63
  The dist-info folder created with recent setuptools already
  contains the version.
* Fri Jul  1 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.15.5
  * Crashes in QClipboard.mimeData(), QTextCursor.currentList() and
    QTextCursor.currentTable() have been fixed.
  * Fixed issues where __feature__ was affected by other imports.
  * Fixed crashes on QImage(uchar *) constructors, related to GIL
    handling.
  * QOpenGLPaintDevice has been added.
- Add patch to fix ARM build failures:
  * 0001-Backport-Fix-GLES-builds.patch
* Fri Jun 17 2022 Ben Greiner <code@bnavigator.de>
- Clean up some deprecated python-rpm-macro usage and declare
  BuildRequirement on it explicitly.
- Provide python dist-info metadata and PyPI names in rpm metadata
- Fix missing install of typing stub and PySide2.support
- Fix ctest suite run by providing some extra paths
* Sat Jun 11 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.15.4
  * [PYSIDE-955]  QOpenGLContext.versionFunctions() have been
  implemented. Class QOpenGLVersionFunctionsFactory (from Qt 6)
  has also been added.
  * [PYSIDE-1409] signature: The decision heuristics of result
  tuples have been refined.
  * [PYSIDE-1438] Crashes in Qt Datavisualization's
  QBar/SurfaceDataProxy add/set/insertRow() members have been
  fixed.
  * [PYSIDE-1502] Import errors will now be properly reported.
  * [PYSIDE-1513] Documentation on properties has been added.
  * [PYSIDE-1538] signature: Unrecognized items will no longer raise
  exceptions.
  * [PYSIDE-1540] The performance of QPainter::drawPoints(QPolygon)
  has been improved.
  * [PYSIDE-1529] Crashes when registering static fields have been
  fixed.
* Sat Mar 12 2022 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.15.3. Bugs fixed:
  * [PYSIDE-454]  namespace std is no longer rejected in the Qt
    typesystem files.
  * [PYSIDE-807]  setup.py's 'clean' command has been fixed.
  * [PYSIDE-1305] The error handling of constructor keyword
    arguments has been fixed.
  * [PYSIDE-1422] A crash related to  Signal and __eq__ has
    been fixed.
  * [PYSIDE-1432] An ownership issue in QLayout::replaceWidget()
    has been fixed.
  * [PYSIDE-1442] QFlags operations have been fixed.
  * [PYSIDE-1447] A crash related to qApp and Python 3.9 has been
    fixed.
  * [PYSIDE-1449] QTestlib's QAbstractItemModelTester has been
    added.
  * [PYSIDE-1460] An infinite loop changing up directories in the
    signature bootstrap code has been fixed.
  * [PYSIDE-1466] The newly introduced overload QSetting.value()
    taking a type has been documentated.
  * [PYSIDE-1478] A bug related to using QQmlContext.setContextProperty()
    with the snake case feature has been fixed.
  * [PYSIDE-1347] Inheritance for enum types has been fixed.
  * [PYSIDE-1448] Code injected at target/end being invoked
    for multiple overload ids has been fixed.
  * [PYSIDE-1470] shiboken.delete() can now be used to delete
    Q*Application.
  * [PYSIDE-1501] The clang parser has been fixed to be able
    to handle some Boost headers.
- Switch to CMake for building pyside2.
- Add patch:
  * 0001-Always-link-to-python-libraries.patch
- Rebase patch:
  * 0001-Don-t-try-to-install-or-use-uic-rcc-designer-copies.patch
- Drop now unneeded patches:
  * lib64.patch
  * 0002-Fix-the-openSUSE-executable-names.patch
- Build pyside without QtWebEngine on powerpc and zSystems
* Tue Oct 12 2021 Christophe Giboudeaux <christophe@krop.fr>
- Backport change from pyside6:
  * 0001-Backport-LLVM-13-fix-from-shiboken6.patch
* Sun Jun 27 2021 Christophe Giboudeaux <christophe@krop.fr>
- Drop the QtWebKit build dependency.
* Fri Apr 23 2021 Christophe Giboudeaux <christophe@krop.fr>
- Exclude internal imports detected by qml-autoreqprov.
* Wed Apr  7 2021 Dirk Müller <dmueller@suse.com>
- avoid repackaging the pkgconfig and cmake directories - they are
  provided by the filesystem package
* Tue Mar 30 2021 John Vandenberg <jayvdb@gmail.com>
- Enable test suite, ignoring two extra test failures
- Update to v5.15.2
  * Projects generating bindings for Qt-based code no longer need to include
    pyside2_global.h for the property and signal/slot annotations to work.
  * [PYSIDE-487] Some missing enumerations and classes were added.
  * [PYSIDE-644] QNetworkCookie was added to WebEngineCore.
  * [PYSIDE-665] A crash when reimplementing QLayout.takeAt() was fixed.
  * [PYSIDE-807] setup.py was rewritten to properly show options
    the in command help.
  * [PYSIDE-972] Launching PySide2 from paths with non-ASCII Latin1
    characters was fixed.
  * [PYSIDE-1019] feature_select: Qt Properties are now represented as
    Python properties.
  * [PYSIDE-1070] A crash when overriding QUiLoader::createWidget()
    in QUiLoader was fixed.
  * [PYSIDE-1082] A crash when creating QMimeData from
    Q(Plain)TextEdit::createMimeDataFromSelection() was fixed.
  * [PYSIDE-1202] More classes from QtConcurrent were added.
  * [PYSIDE-1224] The namespace QColorConstants was added.
  * [PYSIDE-1326] Operators for QFlags on hidden top level namespace
    are now generated.
  * [PYSIDE-1354] Slots being invoked from the wrong thread were fixed.
  * [PYSIDE-1381] The dependency of the QtQml module header on
    internal header pysideqmlregistertype.h was removed.
  * [PYSIDE-1385] Deprecated wheel.pep425tags imports were removed.
  * [PYSIDE-1390] setup.py: The build_rst_docs command was added to
    build rst documentation only
  * [PYSIDE-1397] Functions taking a smart pointer now accept smart
    pointers to base classes.
  * [PYSIDE-1410] QAxBase::dynamicCall() was fixed.
  * [PYSIDE-841] The documentation on modifications was restructured.
  * [PYSIDE-904]  An attribute for generating "using namespace" was added.
  * [PYSIDE-1019] A way of specifying properties for non-Qt classes
    in typesystem XML was added.
  * [PYSIDE-1075] Functions from invisible namespaces are now generated
    into their parent namespaces.
  * [PYSIDE-1224] Variables in namespaces are now generated.
  * [PYSIDE-1366] The order of overloads may now be specified to work
    around problems with the order generated by the overload decisor.
  * [PYSIDE-1388] Final classes with protected methods when disabling
    the protected hack are now correctly generated.
* Tue Sep 15 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.15.1
  * [PYSIDE-74] Implement default __ne__ and __eq__ for all PySide types
  * [PYSIDE-198] Add compatibility with Nuitka
  * [PYSIDE-829] signature: Avoid non-existent attributes in compiled code (Nuitka)
  * [PYSIDE-841] doc: Add widget styling tutorial
  * [PYSIDE-841] add quick painteditem example
  * [PYSIDE-904] Add QObject.findChildren(QRegularExpression)
  * [PYSIDE-904] qp5_tool.py: Add an configuration key for the CMake generator
  * [PYSIDE-904] Port some examples from QRegExp to QRegularExpression
  * [PYSIDE-904] Fix libsample/photon test for Qt 6 / Windows
  * [PYSIDE-904] Enable adding  operators ==, != as functions without code injection
  * [PYSIDE-957] Implement the QEnum/QFlag decorator, V2
  * [PYSIDE-981] Return QVariantList when using list as Signal argument
  * [PYSIDE-1019] feature-select: Implement a selectable feature framework
  * [PYSIDE-1019] feature-select: allow snake_case instead of camelCase for methods
  * [PYSIDE-1019] feature-select: delay the feature switching
  * [PYSIDE-1223] Use pyside2-uic instead of uic for the loadUiType
  * [PYSIDE-1257] Potential fix for deploying with cx_freeze using zip_include_packages
  * [PYSIDE-1282] pthreads: Try to abandon the GIL in case a thread was terminated
  * [PYSIDE-1292] Doc: Enable doc builds using the offline template
  * [PYSIDE-1313] basewrapper.cpp: add PyErr_Fetch/Restore in SbkDeallocWrapperCommon()
  * [PYSIDE-1317] Add QSocketDescriptor class
  * [PYSIDE-1321] Fix leaking reference in PySide2 property getter
  * [PYSIDE-1321] Fix some leaks in enumeration creation
  * [PYSIDE-1323] Add missing Win runtime dll into win wheels
  * [PYSIDE-1323] Update vcredist binaries for MSVC 2019
  * [PYSIDE-1332] Fix crashes in QThread::wait(), QWaitCondition::wait()
  * [PYSIDE-1349] QQmlComponent: allow thread in constructors
  * [PYSIDE-1353] doc: fix Property indentation
  * [PYSIDE-1355] Add Qt3DExtras.QNormalDiffuseMapAlphaMaterial
  * [PYSIDE-1368] __feature__: ignore if `__name__` does not exist in a module
  * [PYSIDE-1372] QDomElement: remove unnecesary setAttribute overloads
  * [PYSIDE-1374] Add the QWidget *-based overloads of the QtWinExtras functions
  * shiboken now accepts multiple headers on the command line.
  * A number of error and warning messages have been prefixed by file name
    and line for better tooling.
  * [PYSIDE-841] Add custom widget shiboken example
  * [PYSIDE-904] shiboken2: Handle virtual methods returning a reference
  * [PYSIDE-1019] shiboken2: Re-add support for parsing Q_PROPERTY
  * [PYSIDE-1177] shiboken: Fix __doc__ setter for derived types
  * [PYSIDE-1325] shiboken: Fix default-initialized function arguments
  * [PYSIDE-1327] shiboken: Resolve typedef'ed base classes
- Add patch to fix doc generation:
  * 0001-cmake-Don-t-assume-qhelpgenerator-is-in-PATH.patch
* Wed May 27 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.15.0
  * [PYSIDE-487] Add API of Qt 5.15
  * [PYSIDE-487] Add support for QSerialPort
  * [PYSIDE-487] Add QtQuickControls2
  * [PYSIDE-841] example: add systray example
  * [PYSIDE-841] doc: add more videos from Qt events
  * [PYSIDE-841] doc: add tutorial for using qrc files
  * [PYSIDE-904] libpyside: Remove deprecated API
  * [PYSIDE-904] Add support for template type aliases
  * [PYSIDE-957] Add a tool to dump meta objects of QObject-derived classes
  * [PYSIDE-1280] Enable injecting raw code for setattro/getattro
  * [PYSIDE-1309] Rename and update some snippets
  * [PYSIDE-454] shiboken: Add a way of specifying system includes to be parsed
  * [PYSIDE-454] shiboken: Handle smart pointers with const pointees
  * [PYSIDE-904] libshiboken: Remove deprecated API
  * [PYSIDE-957] shiboken: Fix refcounts of sbkenum
  * [PYSIDE-990] shiboken: Handle inline namespaces
  * [PYSIDE-1024] shiboken: Make it possible to specify smartpointer instantiations
  * [PYSIDE-1074] shiboken: Fix classes in hidden namespaces
  * [PYSIDE-1188] shiboken: Fix shared pointer return value in virtual function
  * [PYSIDE-1265] shiboken: Introduce a separate logging category for documentation generation
  * [PYSIDE-1265] shiboken: Change debug messages to use qCInfo and remove some messages
  * [PYSIDE-1267] shiboken: Allow for parsing headers under system include paths
  * [PYSIDE-1296] shiboken: Support non-type template parameters in functions
- Drop 0001-shiboken-Support-Clang-version-10.patch. Fixed upstream
- Rebase 0001-Don-t-try-to-install-or-use-uic-rcc-designer-copies.patch
- Rebase lib64.patch
* Thu Apr 23 2020 Christophe Giboudeaux <christophe@krop.fr>
- Add patch to support clang 10:
  * 0001-shiboken-Support-Clang-version-10.patch
* Wed Feb 26 2020 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.14.1
  * [PYSIDE-841] Add example for Threads and Signals
  * [PYSIDE-1135] qApp: Ensure QtCore import when embedded QApplication subclass is used
  * [PYSIDE-1158] Let qApp be noApp instead of pretending to be None
  * [PYSIDE-1164] qApp: make sure to create the right instance when embedding
  * [PYSIDE-1165] designer: patch rpath for unix
  * [PYSIDE-1192] libpyside: Set default signal name only if previously assigned
  * [PYSIDE-1201] docs: Fix pre overlap and improve reading
  * [PYSIDE-1205] libpyside: avoid freeing char*
  * [PYSIDE-1207] Fix ownership of QTextDocument::createObject
  * [PYSIDE-1191] shiboken: Introduce "until" version attribute as opposite of "since"
* Mon Dec 30 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.14.0:
  * 
  * [PYSIDE-990] It is no longer possible to nest types in typesystem files by
    by qualifying the namespace components with "::". The elements need to be
    properly nested.
  * [PYSIDE-487] Add bindings for Qt 5.14
  * [PYSIDE-785] Release ownership in QAbstractVideoFilterWrapper::createFilterRunnable
  * [PYSIDE-795] Create a framework for deprecated functions
  * [PYSIDE-795] Make the function registry more usable in Python modules
  * [PYSIDE-795] Improve the NumPy Support by iterables
  * [PYSIDE-820] Fix booleans and empty list cases in QSettings
  * [PYSIDE-849] Add inject-code for QVideoFrame::bits()
  * [PYSIDE-939] Add support for Python 3.8
  * [PYSIDE-939] Fix refcount issues with QSettings glue code
  * [PYSIDE-939] Finalize the Python 3.8 refcount fix
  * [PYSIDE-951] Support Pointer Primitive Types by Arrays or Result Tuples
  * [PYSIDE-1007] Remove extra ref on QDataStream::setDevice
  * [PYSIDE-1033] CMake modularization: macros creation
  * [PYSIDE-1041] Enable multimedia classes after API fixup
  * [PYSIDE-1047] QtWinExtras: Add QtWin namespace
  * [PYSIDE-1051] Fix heaptype conflict with QtCore.QObject.__new__in Python 2.7
  * [PYSIDE-1052] Add QtCore.Slot.__signature__ and much more manually
  * [PYSIDE-1059] Documentation: update QInputDialog snippets
  * [PYSIDE-1066] Fix Xcode sdk value embedded into PySide2 binaries
  * [PYSIDE-1067] Update docs style
  * [PYSIDE-1067] New documentation structure
  * [PYSIDE-1068] Add designer to the pyside tools
  * [PYSIDE-1073] Fix a typing bug in Python 2.7 and update
  * [PYSIDE-1077] Fix wrong Python init return codes
  * [PYSIDE-1079] signature: Support typing.Optional[T] and refine a bit
  * [PYSIDE-1089] Fix formatting of the deployment documentation
  * [PYSIDE-1093] Fix bad shutdown effect on QApplication.instance()
  * [PYSIDE-1098] Replace pyside2-uic/pyside2-rcc by uic/rcc which now have an
    option to generate Python
  * [PYSIDE-1101] Remove QGraphicsItem::scroll from QtChart
  * [PYSIDE-1140] Add python_requires to the python setup
  * [QTBUG-66304] Blacklist failing QtPositioning test
  * [PYSIDE-454] Fix crash when smartptr template class cannot be found
  * [PYSIDE-1037] Allow for "auto" as target of type for CONVERTTOCPP in injected code
  * [PYSIDE-1095] Fix handling of modified default expressions
- Drop 0001-Remove-unnecessary-she-bang-from-icon-cache.py.patch. pyside2uic is gone
- Add patches:
  * 0001-Don-t-try-to-install-or-use-uic-rcc-designer-copies.patch to prevent file conflicts
  * 0002-Fix-the-openSUSE-executable-names.patch to use the -qt5 suffix
* Thu Dec 19 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the license tags.
* Thu Dec 12 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update the minimum Qt version to 5.14
* Sat Dec  7 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.2
  * [PYSIDE-785] Release ownership in QAbstractVideoFilterWrapper::createFilterRunnable
  * [PYSIDE-820] Fix booleans and empty list cases in QSettings
  * [PYSIDE-849] Add inject-code for QVideoFrame::bits()
  * [PYSIDE-1007] Remove extra ref on QDataStream::setDevice
  * [PYSIDE-1019] libpyside: Fix compiler warning
  * [PYSIDE-1049] Split build instructions to build and packaging
  * [PYSIDE-1051] Fix heaptype conflict with QtCore.QObject.__new__in Python 2.7
  * [PYSIDE-1089] Fix formatting of the deployment documentation
  * [PYSIDE-1093] Fix bad shutdown effect on QApplication.instance()
  * [PYSIDE-1095] shiboken: Fix handling of modified default expressions
* Sun Sep  8 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.1
  * [Fixes https://github.com/spyder-ide/qtpy/issues/195] Fix RuntimeError: dictionary changed size during iteration
  * [PYSIDE-634] Add support for parameterNames in Signals
  * [PYSIDE-951] Cleanup signature module before substantial change
  * [PYSIDE-951] correct QtPrintSupport dependency
  * [PYSIDE-1010] Add optional support for types in QSettings::value
  * [PYSIDE-1020] Fix pyside2-uic to generate correct code for QWebview and QQuickWidget
  * [PYSIDE-1028] Leave QVariantMap as a name, not a type
  * [PYSIDE-1033] CMake modularization: macros creation
  * [PYSIDE-1035] Fix pyside2-uic to generate correct code for QTableWidget
  * [PYSIDE-1051] Fix heaptype conflict with QtCore.QObject.__new__in Python 2.7
  * [PYSIDE-1052] Add QtCore.Slot.__signature__ and much more manually
  * [PYSIDE-1059] Documentation: update QInputDialog snippets
  * [PYSIDE-1066] Fix Xcode sdk value embedded into PySide2 binaries
  * [PYSIDE-1067] Update docs style
  * [PYSIDE-1073] Fix a typing bug in Python 2.7 and update
  * [PYSIDE-1077] Fix wrong Python init return codes
  * [PYSIDE-1079] signature: Support typing.Optional[T] and refine a bit
  * [PYSIDE-1024] shiboken: Generate code for smart pointers only within declaring package
  * [PYSIDE-1037] shiboken: Allow for "auto" as target of type for CONVERTTOCPP in injected code
- Drop patches, now upstream:
  * 0002-Fix-qApp-import-of-QCoreApplication.patch
  * 0003-PySide2-QtCore-Remove-duplicated-type-entry-for-bool.patch
- Refresh lib64.patch
* Wed Jul 10 2019 Tuukka Pasanen <tuukka.pasanen@ilmi.fi>
- Add patches to make FreeCAD not crash at start
  * 0002-Fix-qApp-import-of-QCoreApplication.patch
  * 0003-PySide2-QtCore-Remove-duplicated-type-entry-for-bool.patch
* Mon Jul  1 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Remove "CFLAGS=-I/usr/include/linux" export, otherwise pthreads.h
  includes linux/time.h instead of time.h. As a result CMake no longer
  finds a valid pthreads.h and aborts.
- Drop "docs", which included building and installing instructions only,
  as done upstream. See https://doc.qt.io/qtforpython/ and
  https://wiki.qt.io/Qt_for_Python/Tutorial for developer documentation.
* Thu Jun 27 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.13.0
  * Add bindings for 5.13
  * Support the qApp macro in "scriptable application"
  * Doc: Add QML Integration tutorial
  * Docs: Add Expenses tool tutorial
  * Regenerate all example forms using the python-extended rcc of 5.14
  * Fix type name for lookup of QFlags<> converters
  Check the changes-* files for older changes.
* Mon May  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.3. No changelog available for this version.
- Fix the license tag, the shiboken2 subdir uses a different license.
* Sat Apr  6 2019 Christophe Giboudeaux <christophe@krop.fr>
- Update to 5.12.2
  * Added binding for QWebEngineUrlScheme
  * Fixed a crash related to multiple inheritance
  * Fixed wrong METADATA for generated wheels
  * Prevent Python 3.5 from crashing the build
  Check the changes-* files for the complete list of changes.
- Drop fix-cmake.patch
- Drop 0001-Avoid-creation-of-empty-build-directories-in-install.patch
- Refresh lib64.patch
- Drop the unused _service file.
* Fri Dec 28 2018 Fabian Vogt <fabian@ritter-vogt.de>
- Use %%python_sitearch instead of %%py_sitedir
* Mon Dec 24 2018 Jan Engelhardt <jengelh@inai.de>
- Avoid repeating the name in the summary.
* Wed Dec 19 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.12
- Package examples
- Include PEP484 type hints
- Use parallel make
- Rebase lib64.patch
- Drop fix_build.patch, obsoleted by upstream changes
- Add 0001-Avoid-creation-of-empty-build-directories-in-install.patch
- Add 0001-Remove-unnecessary-she-bang-from-icon-cache.py.patch
* Wed Oct 24 2018 Adrian Schröter <adrian@suse.de>
- enable support for Qt5Scxml
- cleanup python2 deps
- enable doc generation
* Tue Oct 23 2018 Christophe Giboudeaux <christophe@krop.fr>
- Add fix_build.patch to fix an error reported by the post build checks.
* Mon Oct 22 2018 Adrian Schröter <adrian@suse.de>
- update to version 5.11.2 tag
* Tue Jun  5 2018 christophe@krop.fr
- Update license to LGPL-3.0-only OR (GPL-2.0-only OR GPL-3.0-or-later)
* Fri Apr 27 2018 adrian@suse.de
- build against Qt 5.11
* Tue Mar 13 2018 adrian@suse.de
- disable python2 build
  No one needs it atm and it is conflicting at installation time
  with python3 variant
* Mon Mar  5 2018 adrian@suse.de
- update to current snapshot from dev branch for Qt 5.10
- make test optional
- fix-cmake.patch lib64.patch for fixing build and installation
* Sat Mar  3 2018 adrian@suse.de
- build fix
* Thu Sep 14 2017 kkaempf@suse.com
- add Qt5-svg support
* Wed Jun 28 2017 jengelh@inai.de
- Trim filler wording from description.
* Mon Jun 12 2017 adrian@suse.de
- initial package of PySide2 for Qt5.9
- includes also shiboken
